==> vmaid-1.9.0.tar.gz: vmaid-1.9.0/src/file.h <==
/*
    Video maid
    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef __FILE_H__
#define __FILE_H__


#include "vmaid.h"


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


#define FILE_SAVE_AVI 0
#define FILE_SAVE_BITMAP 1
#define FILE_SAVE_WAVE 2
#define FILE_SAVE_SCENARIO 2


typedef struct FileOpen_Tag {
    gchar *file;
    gboolean merge;
} FileOpen;
typedef struct FileSave_Tag {
    gchar *file;
    AviEdit *avi_edit[3];
    AviSave *avi_save;
} FileSave;


/******************************************************************************
*                                                                             *
* ja:ファイル入力関数群                                                       *
*                                                                             *
******************************************************************************/
/*  ja:ファイルを開く(独立スレッド)
    file_open,Open情報
          RET,ウインドウ情報                                                */
VmaidWindow *
file_open_edit (FileOpen *file_open);


/*  ja:AVIファイルを保存する(独立スレッド)
    file_save,Save情報
          RET,TRUE:正常終了,FALSE:エラー                                    */
gboolean
file_save_edit (FileSave *file_save);


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif

==> vmaid-1.9.3.tar.gz: vmaid-1.9.3/src/file.h <==
/*
    Video maid
    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef __FILE_H__
#define __FILE_H__


#include "vmaid.h"


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


#define FILE_SAVE_AVI 0
#define FILE_SAVE_BITMAP 1
#define FILE_SAVE_WAVE 2
#define FILE_SAVE_SCENARIO 2


typedef struct _FileOpen {
    gchar *file;
    gboolean merge;
} FileOpen;
typedef struct _FileSave {
    gchar *file;
    AviEdit *avi_edit[3];
    AviSave *avi_save;
} FileSave;


/******************************************************************************
*                                                                             *
* ja:ファイル入力関数群                                                       *
*                                                                             *
******************************************************************************/
/*  ja:ファイルを開く(独立スレッド)
    file_open,Open情報
          RET,ウインドウ情報                                                */
VmaidWindow *
file_open_edit (FileOpen *file_open);


/*  ja:AVIファイルを保存する(独立スレッド)
    file_save,Save情報
          RET,TRUE:正常終了,FALSE:エラー                                    */
gboolean
file_save_edit (FileSave *file_save);


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __FILE_H__ */
